==> servicecatalog-model-5.10.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceClassSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ServiceClassSpecBuilder extends io.fabric8.servicecatalog.api.model.ServiceClassSpecFluentImpl<io.fabric8.servicecatalog.api.model.ServiceClassSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.servicecatalog.api.model.ServiceClassSpec,io.fabric8.servicecatalog.api.model.ServiceClassSpecBuilder>{
  public ServiceClassSpecBuilder() {
    this(false);
  }
  public ServiceClassSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ServiceClassSpec(), validationEnabled);
  }
  public ServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceClassSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ServiceClassSpec(), validationEnabled);
  }
  public ServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceClassSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ServiceClassSpec instance) {
    this(fluent, instance, false);
  }
  public ServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceClassSpecFluent<?> fluent,io.fabric8.servicecatalog.api.model.ServiceClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBindable(instance.getBindable()); 
    fluent.withBindingRetrievable(instance.getBindingRetrievable()); 
    fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withExternalID(instance.getExternalID()); 
    fluent.withExternalMetadata(instance.getExternalMetadata()); 
    fluent.withExternalName(instance.getExternalName()); 
    fluent.withPlanUpdatable(instance.getPlanUpdatable()); 
    fluent.withRequires(instance.getRequires()); 
    fluent.withServiceBrokerName(instance.getServiceBrokerName()); 
    fluent.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceClassSpec instance) {
    this(instance,false);
  }
  public ServiceClassSpecBuilder(io.fabric8.servicecatalog.api.model.ServiceClassSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBindable(instance.getBindable()); 
    this.withBindingRetrievable(instance.getBindingRetrievable()); 
    this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    this.withDescription(instance.getDescription()); 
    this.withExternalID(instance.getExternalID()); 
    this.withExternalMetadata(instance.getExternalMetadata()); 
    this.withExternalName(instance.getExternalName()); 
    this.withPlanUpdatable(instance.getPlanUpdatable()); 
    this.withRequires(instance.getRequires()); 
    this.withServiceBrokerName(instance.getServiceBrokerName()); 
    this.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.servicecatalog.api.model.ServiceClassSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.servicecatalog.api.model.ServiceClassSpec build() {
    ServiceClassSpec buildable = new ServiceClassSpec(fluent.getBindable(),fluent.getBindingRetrievable(),fluent.getDefaultProvisionParameters(),fluent.getDescription(),fluent.getExternalID(),fluent.getExternalMetadata(),fluent.getExternalName(),fluent.getPlanUpdatable(),fluent.getRequires(),fluent.getServiceBrokerName(),fluent.getTags());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ServiceClassSpecBuilder that = (ServiceClassSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> servicecatalog-model-6.6.2-sources.jar: io/fabric8/servicecatalog/api/model/ServiceClassSpecBuilder.java <==
package io.fabric8.servicecatalog.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ServiceClassSpecBuilder extends ServiceClassSpecFluentImpl<ServiceClassSpecBuilder> implements VisitableBuilder<ServiceClassSpec,ServiceClassSpecBuilder>{
  public ServiceClassSpecBuilder() {
    this(false);
  }
  public ServiceClassSpecBuilder(Boolean validationEnabled) {
    this(new ServiceClassSpec(), validationEnabled);
  }
  public ServiceClassSpecBuilder(ServiceClassSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ServiceClassSpecBuilder(ServiceClassSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ServiceClassSpec(), validationEnabled);
  }
  public ServiceClassSpecBuilder(ServiceClassSpecFluent<?> fluent,ServiceClassSpec instance) {
    this(fluent, instance, false);
  }
  public ServiceClassSpecBuilder(ServiceClassSpecFluent<?> fluent,ServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBindable(instance.getBindable()); 
    fluent.withBindingRetrievable(instance.getBindingRetrievable()); 
    fluent.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withExternalID(instance.getExternalID()); 
    fluent.withExternalMetadata(instance.getExternalMetadata()); 
    fluent.withExternalName(instance.getExternalName()); 
    fluent.withPlanUpdatable(instance.getPlanUpdatable()); 
    fluent.withRequires(instance.getRequires()); 
    fluent.withServiceBrokerName(instance.getServiceBrokerName()); 
    fluent.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  public ServiceClassSpecBuilder(ServiceClassSpec instance) {
    this(instance,false);
  }
  public ServiceClassSpecBuilder(ServiceClassSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withBindable(instance.getBindable()); 
    this.withBindingRetrievable(instance.getBindingRetrievable()); 
    this.withDefaultProvisionParameters(instance.getDefaultProvisionParameters()); 
    this.withDescription(instance.getDescription()); 
    this.withExternalID(instance.getExternalID()); 
    this.withExternalMetadata(instance.getExternalMetadata()); 
    this.withExternalName(instance.getExternalName()); 
    this.withPlanUpdatable(instance.getPlanUpdatable()); 
    this.withRequires(instance.getRequires()); 
    this.withServiceBrokerName(instance.getServiceBrokerName()); 
    this.withTags(instance.getTags()); 
    this.validationEnabled = validationEnabled; 
  }
  ServiceClassSpecFluent<?> fluent;
  Boolean validationEnabled;
  public ServiceClassSpec build() {
    ServiceClassSpec buildable = new ServiceClassSpec(fluent.getBindable(),fluent.getBindingRetrievable(),fluent.getDefaultProvisionParameters(),fluent.getDescription(),fluent.getExternalID(),fluent.getExternalMetadata(),fluent.getExternalName(),fluent.getPlanUpdatable(),fluent.getRequires(),fluent.getServiceBrokerName(),fluent.getTags());
    return buildable;
  }
  
}
